package de.uni_passau.fim.gui;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Color;
import android.graphics.drawable.ColorDrawable;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.StateListDrawable;
import android.util.AttributeSet;
import android.widget.RadioButton;
import de.uni_passau.fim.R;

/**
 * This class extends the RadioButton to provide the possibility to
 * assign a selectable color. The color gets an unique ID. 
 * 
 * TODO: Just use it.
 */
public final class ColorRadioButton extends RadioButton {

	/**
	 * The color assigned to this RadioButton 
	 */
	private int color;
	/**
	 * The unique ID of the color
	 */
	public int colorID;
	/**
	 * The unique ID for the next created instance
	 */
	public static int nextColorID = 0;
	
	/**
	 * Creates a new instance of ColorButton.
	 */
	public ColorRadioButton(Context context) {
		super(context);
	}

	/**
	 * Creates a new instance of ColorButton.
	 */
	public ColorRadioButton(Context context, AttributeSet attrs) {
		super(context, attrs);
		init(attrs);
	}

	/**
	 * Creates a new instance of ColorButton.
	 */
	public ColorRadioButton(Context context, AttributeSet attrs, int defStyle) {
		super(context, attrs, defStyle);
		init(attrs);
	}

	/**
	 * Returns the color
	 * 
	 * @return the color
	 */
	public final int getColor() {
		return this.color;
	}
	
	/**
	 * Returns the unique ID of the color
	 * 
	 * @return the unique ID of the color
	 */
	public final int getColorID() {
		return this.colorID;
	}
	
	/**
	 * This method is called by the constructors. It initializes the 
	 * fields and generates the two-color-background.
	 * 
	 * @param attrs
	 */
	private void init(AttributeSet attrs) {
		// Assign unique ID
		this.colorID = nextColorID;
		nextColorID++;
		
		// Assign color
		TypedArray a = getContext().obtainStyledAttributes(attrs,R.styleable.ColorRadioButton);
		this.color = a.getColor(R.styleable.ColorRadioButton_selectedColor, 0xFF000000);
		
		// Generate the background
		StateListDrawable bg = new StateListDrawable();
		Drawable checkedBg = new ColorDrawable(color);
		// Calculate the second color for the button
		int g = Color.green(color);
		int b = Color.blue(color);
		int r = Color.red(color);
		g = g > 0x55 ? g-0x55 : 0;
		b = b > 0x55 ? b-0x55 : 0;
		r = r > 0x55 ? r-0x55 : 0;
		Drawable defaultBg = new ColorDrawable(Color.rgb(r, g, b));
		bg.addState(new int[]{android.R.attr.state_checked}, checkedBg);
		bg.addState(new int[1], defaultBg);
		setBackgroundDrawable(bg);
		
		// Remove the default radio button
		Drawable empty = new ColorDrawable(0);
		setButtonDrawable(empty);
	}
}
